(***********************************************************************)
(*                                                                     *)
(*                       Ambients in JoCaml                            *)
(*                                                                     *)
(*               Alan Schmitt, projet Para, INRIA Rocquencourt         *)
(*                                                                     *)
(*  Copyright 1999 Institut National de Recherche en Informatique et   *)
(*  Automatique.  Distributed only by permission.                      *)
(*                                                                     *)
(***********************************************************************)

open Syntax
  
let rec print_process = function
    Par (p1, p2) -> print_string "("; print_process p1; print_string " | "; print_process p2; print_string ")"
  | Seq (c, p) -> print_capa c; print_string "."; print_process p
  | Amb (name, p, b) -> print_name name; print_string "["; print_process p; print_string"]"
  | New (name, p) -> print_string ("nu "^name^"."); print_process p
  | Comm_in (name, p) -> print_string ("("^name^")."); print_process p
  | Comm_out capa -> print_string "<"; print_capa capa; print_string ">"
  | Bang p -> print_string "!("; print_process p; print_string")"
  | Zero -> print_string "0"
	
and print_capa = function
    Seq_capa (c1, c2) -> print_capa c1; print_string "."; print_capa c2
  | In name -> print_string "in "; print_name name
  | Out name -> print_string "out "; print_name name
  | Open name -> print_string "open "; print_name name
  | Name name -> print_name name
  | Yell str -> print_string ("\""^str^"\"")

and print_name = function
    Ident n -> print_string n
  | ResolvedName n -> print_string n
      
let print_amb_expr e =
  print_process e; print_newline ()
